@@ -6,12 +6,16 @@
 
 
 /*
- * Copyright (c) 2005 QUALCOMM Incorporated.  All rights reserved.
+ * Copyright (c) 2008 QUALCOMM Incorporated.  All rights reserved.
  * The file License.txt specifies the terms for use, modification,
  * and redistribution.
  *
  * Revisions:
  *
+ * 05/18/07  [rg]
+ *         - Correct milliseconds calculation (thanks to Jose Marcio
+ *           Martins da Cruz for the patch).
+ *
  * 02/09/01  [rg]
  *         - Include year.
  *
@@ -135,7 +139,7 @@ pop_logv ( POP         *p,         /* the source of all things */
         iDateLen  = strlen ( pDate ); /* length including year */
         pYear     = pDate + ( iDateLen - 5 ); /* point to start of year */
         date_time [ iDateLen - 2 ] = '\0'; /* cut off the year */
-        lMsec     = (tval.tv_usec + 500) / 1000; /* convert useconds to milliseconds */
+        lMsec     = (tval.tv_usec) / 1000; /* convert useconds to milliseconds */
         fprintf ( p->trace, "%s.%03ld %.4s [%ld] %s\n", 
                   pDate, lMsec, pYear, (long) getpid(), msgbuf );
         fprintf ( p->trace, "%s.%03ld %.4s \n", pDate, lMsec, pYear );
