@@ -6,7 +6,7 @@
 
 
 /*
- * Copyright (c) 2005 QUALCOMM Incorporated.  All rights reserved.
+ * Copyright (c) 2008 QUALCOMM Incorporated.  All rights reserved.
  * The file License.txt specifies the terms for use, modification,
  * and redistribution.
  *
@@ -152,6 +152,10 @@
 #  include <sys/unistd.h>
 #endif
 
+#if HAVE_CRYPT_H
+#  include <crypt.h>
+#endif
+
 #include <time.h>
 #include <pwd.h>
 #include "popper.h"
@@ -178,45 +182,9 @@ char    *ERRMSG_ACEXP = "[AUTH] \"%s\": account expired.";
 char    *ERRMSG_PWEXP = "[AUTH] \"%s\": password expired.";
 char    *ERRMSG_AUTH  = "[AUTH] \"%s\": access denied.";
 
-/*------------------------------------- PASSWORD */
+
 pop_result
-check_password ( POP *p, char *password_entry, char *password_claim )
-{
-    /*
-     * First check if password entry (system password) is null
-     */
-    if ( (  password_entry == NULL ) || 
-         ( *password_entry == '\0' )   ) {
-        sleep ( SLEEP_SECONDS );
-        return ( pop_msg ( p, POP_FAILURE, HERE, ERRMSG_PW, p->user ) );
-    }
-
-    /*
-     * Now compare the claimed password with the system password entry
-     *
-     * Linux kernels older than 2.0.x need pw_encrypt() for shadow support 
-     */
-    if ( TRUE
-#ifdef    HAVE_CRYPT16
-         && strcmp ( crypt16    ( password_claim, password_entry ), password_entry )
-#endif /* HAVE_CRYPT16 */
-#ifdef    HAVE_BIGCRYPT
-         && strcmp ( bigcrypt   ( password_claim, password_entry ), password_entry )
-#endif /* HAVE_BIGCRYPT */
-#ifdef   HAVE_PW_ENCRYPT
-         && strcmp ( pw_encrypt ( password_claim, password_entry ), password_entry )
-#endif /* HAVE_PW_ENCRYPT */
-#ifdef    HAVE_CRYPT
-         && strcmp ( crypt      ( password_claim, password_entry ), password_entry )
-#endif /* HAVE_CRYPT */
-       ) {
-        sleep  ( SLEEP_SECONDS );
-        return ( pop_msg ( p, POP_FAILURE, HERE, ERRMSG_PW, p->user ) );
-    }
-
-    return POP_SUCCESS;
-}
-
+check_password ( POP *p, char *password_entry, char *password_claim );
 
 
 
@@ -674,10 +642,10 @@ struct passwd *pw;
 #      ifdef SECURENISPLUS
     uid_save = geteuid();
     if ( uid_save )
-        seteuid ( 0 ) ; /* must first try as root */
+        SETEUID ( 0 ) ; /* must first try as root */
     pwd = getspnam ( p->user );
     if ( pwd == NULL || strlen ( pwd->sp_pwdp ) < 8 ) {
-        seteuid ( uid_save ); /* now try as the user */
+        SETEUID ( uid_save ); /* now try as the user */
         pwd = getspnam ( p->user );
     }
 #      else /* not using SECURENISPLUS */
@@ -1210,7 +1178,7 @@ pop_pass ( POP *p )
      * we must do this keyserv stuff (as well as auth_user()!) as the user 
      */
     uid_save = geteuid();
-    seteuid ( pwp->pw_uid );
+    SETEUID ( pwp->pw_uid );
 
     /*  
      * see if DES keys are already known to the keyserv(1m) 
@@ -1240,7 +1208,7 @@ pop_pass ( POP *p )
              * either resides in /etc/shadow or "root" has access to the
              * corresponding NIS+ entry 
              */
-            seteuid ( 0 );
+            SETEUID ( 0 );
         }
     }
 #endif /* SECURENISPLUS */
@@ -1301,7 +1269,7 @@ pop_pass ( POP *p )
     }
 
 #ifdef SECURENISPLUS
-    seteuid ( uid_save );
+    SETEUID ( uid_save );
 #endif /* SECURENISPLUS */
 
     /*
@@ -1368,3 +1336,60 @@ pop_pass ( POP *p )
                         p->drop_size ) );
 }
 
+
+/*------------------------------------- PASSWORD */
+pop_result
+check_password ( POP *p, char *password_entry, char *password_claim )
+{
+
+#ifdef _XOPEN_SOURCE
+    DEBUG_LOG0 ( p, "_XOPEN_SOURCE defined" );
+#else
+    DEBUG_LOG0 ( p, "_XOPEN_SOURCE not defined" );
+#endif
+#ifdef _XOPEN_VERSION
+    DEBUG_LOG1 ( p, "_XOPEN_VERSION = %i", _XOPEN_VERSION );
+#else
+    DEBUG_LOG0 ( p, "_XOPEN_VERSION not defined" );
+#endif
+#ifdef __EXTENSIONS__
+    DEBUG_LOG0 ( p, "__EXTENSIONS__ defined" );
+#else
+    DEBUG_LOG0 ( p, "__EXTENSIONS__ not defined" );
+#endif
+
+    /*
+     * First check if password entry (system password) is null
+     */
+    if ( (  password_entry == NULL ) || 
+         ( *password_entry == '\0' )   ) {
+        sleep ( SLEEP_SECONDS );
+        return ( pop_msg ( p, POP_FAILURE, HERE, ERRMSG_PW, p->user ) );
+    }
+
+    /*
+     * Now compare the claimed password with the system password entry
+     *
+     * Linux kernels older than 2.0.x need pw_encrypt() for shadow support 
+     */
+    if ( TRUE
+#ifdef    HAVE_CRYPT16
+         && strcmp ( crypt16    ( password_claim, password_entry ), password_entry )
+#endif /* HAVE_CRYPT16 */
+#ifdef    HAVE_BIGCRYPT
+         && strcmp ( bigcrypt   ( password_claim, password_entry ), password_entry )
+#endif /* HAVE_BIGCRYPT */
+#ifdef   HAVE_PW_ENCRYPT
+         && strcmp ( pw_encrypt ( password_claim, password_entry ), password_entry )
+#endif /* HAVE_PW_ENCRYPT */
+#ifdef    HAVE_CRYPT
+         && strcmp ( crypt      ( password_claim, password_entry ), password_entry )
+#endif /* HAVE_CRYPT */
+       ) {
+        sleep  ( SLEEP_SECONDS );
+        return ( pop_msg ( p, POP_FAILURE, HERE, ERRMSG_PW, p->user ) );
+    }
+
+    return POP_SUCCESS;
+}
+
