@@ -424,8 +424,7 @@ typedef enum {
  */
 typedef enum {                               /* Config file option is:         */
     CfgBool = 1,                             /* - boolean                      */
-    CfgInt,                                  /* - integer (positive)           */
-    CfgIntNeg,                               /* - integer, may be negative     */
+    CfgInt,                                  /* - integer                      */
     CfgMnem,                                 /* - mnemonic                     */
     CfgStr,                                  /* - string                       */
     CfgBad                                   /* - INVALID VALUE                */
